from setuptools import setup, find_packages

setup(
    name="sortByTanvir",
    version="0.0.2",
    packages=find_packages(),
    install_requires=[],
    entry_points={},
    description="A simple sorting algorithms education package",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Tanvir-yzu",
    author_email="2020tanvir1971@gmail.com",
    url="https://github.com/Tanvir-yzu/sortByTanvir.git",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Education",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
    ],
    keywords=["sorting algorithms education","Tanvir-yzu","sortByTanvir","sorting"]
)

